<?php
/*
  ##############################################################################
  # iProduction - Production and Manufacture Management
  ##############################################################################
  # AUTHOR:		Door Soft
  ##############################################################################
  # EMAIL:		info@doorsoft.co
  ##############################################################################
  # COPYRIGHT:		RESERVED BY Door Soft
  ##############################################################################
  # WEBSITE:		https://www.doorsoft.co
  ##############################################################################
  # This is Attendance Model
  ##############################################################################
 */
namespace App;

use Illuminate\Database\Eloquent\Model;
use Carbon\Carbon;

class Attendance extends Model
{
    protected $table = "tbl_attendance";
    
    
    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    
    public $timestamps = false;

    protected $guarded = ["id"];

    /**
     * User Relationship
     */
    public function user($value='')
    {
        return $this->belongsTo(User::class, 'employee_id', 'id');
    }

    /**
     * Added By Relation with User
     */
    public function addedBy($value='')
    {
        return $this->belongsTo(User::class, 'user_id', 'id');
    }
    
     public function scopeByMonth($query, $month)
    {
        return $query->whereRaw("DATE_FORMAT(date, '%Y-%m') = ?", [$month]);
    }
    
    public function getWorkHoursAttribute()
    {
        if (!$this->in_time || !$this->out_time) {
            return null; // Return null if in_time or out_time is missing
        }
    
        $inTime = Carbon::parse($this->in_time);
        $outTime = Carbon::parse($this->out_time);
    
        return $inTime->diffInHours($outTime);
    }
    
    public function getIsHalfDayAttribute()
    {
        return $this->work_hours < 11; // If work hours are less than 11, it's a half-day
    }
}


